@@ -1,13 +1,11 @@
 'use strict';
 
-// Load modules
 
-const NodeUtil = require('util');
+const Util = require('util');
 
-const Hoek = require('hoek');
+const Hoek = require('@hapi/hoek');
 
 
-// Declare internals
 
 const internals = {
     flags: ['not', 'once', 'only', 'part', 'shallow'],
@@ -187,7 +185,7 @@ internals.addMethod('error', function (...args /*type, message*/) {
 
 [true, false, null, undefined].forEach((value) => {
 
-    const name = NodeUtil.inspect(value);
+    const name = Util.inspect(value);
     const method = function () {
 
         return this.assert(this._ref === value, 'be ' + name);
@@ -272,7 +270,7 @@ internals.addMethod('length', internals.length);
 internals.equal = function (value, options) {
 
     options = options || {};
-    const settings = Hoek.applyToDefaults({ prototype: exports.settings.comparePrototypes }, options);
+    const settings = Hoek.applyToDefaults({ prototype: exports.settings.comparePrototypes, deepFunction: true }, options);
 
     const compare = this._flags.shallow ? (a, b) => a === b
         : (a, b) => Hoek.deepEqual(a, b, settings);
@@ -460,7 +458,7 @@ internals.isPromise = function (promise) {
 
 internals.display = function (value) {
 
-    const string = value instanceof Error ? `[${value.toString()}]` : (internals.isPromise(value) ? '[Promise]' : NodeUtil.inspect(value));
+    const string = value instanceof Error ? `[${value.toString()}]` : (internals.isPromise(value) ? '[Promise]' : Util.inspect(value));
 
     if (!exports.settings.truncateMessages || string.length <= 40) {
         return string;
@@ -518,12 +516,18 @@ internals.type = function (value) {
 };
 
 
+internals.atNamedRx = /^\s*at [^(/]*\(?(.+)\:(\d+)\:(\d+)\)?$/;
+
+
+internals.atUnnamedRx = /^\s*at (.+)\:(\d+)\:(\d+)\)?$/;
+
+
 exports.thrownAt = function (error) {
 
     error = error || new Error();
     const stack = typeof error.stack === 'string' ? error.stack : '';
     const frame = stack.replace(error.toString(), '').split('\n').slice(1).filter(internals.filterLocal)[0] || '';
-    const at = frame.match(/^\s*at [^(]*\(?(.+)\:(\d+)\:(\d+)\)?$/);
+    const at = frame.match(frame.includes('(') ? internals.atNamedRx : internals.atUnnamedRx);
     return Array.isArray(at) ? {
         filename: at[1],
         line: at[2],
