@@ -1,21 +1,16 @@
 'use strict';
 
-// Load modules
 
 const Util = require('util');
 
-const Hoek = require('hoek');
-const Lab = require('lab');
+const Hoek = require('@hapi/hoek');
+const Lab = require('@hapi/lab');
 const Code = require('..');
 
 
-// Declare internals
-
 const internals = {};
 
 
-// Test shortcuts
-
 const { describe, it } = exports.lab = Lab.script();
 
 
@@ -148,7 +143,8 @@ describe('expect()', () => {
         }
 
         Code.settings.truncateMessages = origTruncate;
-        Hoek.assert(exception.message === 'Expected [ 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18 ] to be a string but got \'array\'', exception);
+        const message = exception.message.replace(/\n/g, '').replace(/ {2,}/g, ' ').replace(']', ' ]');
+        Hoek.assert(message === 'Expected [ 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18 ] to be a string but got \'array\'', exception);
     });
 
     it('asserts on invalid condition (large object, display truncated)', () => {
@@ -194,11 +190,8 @@ describe('expect()', () => {
 
         Code.settings.truncateMessages = origTruncate;
 
-        const lines = exception.message.split('\n');
-
-        Hoek.assert(lines.length === 2, exception);
-        Hoek.assert(lines[0].trim() === 'Expected { a: 1,', exception);
-        Hoek.assert(lines[1].trim() === 'b: \'12345678901234567890123456789012345678901234567890\' } to be a string but got \'object\'', exception);
+        const message = exception.message.replace(/\n/g, '').replace(/ {2,}/g, ' ');
+        Hoek.assert(message === `Expected { a: 1, b: '12345678901234567890123456789012345678901234567890' } to be a string but got 'object'`, exception);
     });
 
     it('asserts on invalid condition (long object values, display truncated)', () => {
@@ -474,8 +467,7 @@ describe('expect()', () => {
 
             it('validates assertion (not error)', () => {
 
-                const Custom = function () { };
-                Hoek.inherits(Custom, Error);
+                const Custom = class extends Error { };
 
                 try {
                     Code.expect(false).to.not.be.an.error();
@@ -541,8 +533,7 @@ describe('expect()', () => {
 
             it('validates assertion (missing message)', () => {
 
-                const Custom = function () { };
-                Hoek.inherits(Custom, Error);
+                const Custom = class extends Error { };
 
                 try {
                     Code.expect(new Custom()).to.be.an.error('kaboom');
@@ -596,7 +587,7 @@ describe('expect()', () => {
             it('invalidates assertion (anonymous type)', () => {
 
                 const Custom = function () { };
-                Hoek.inherits(Custom, Error);
+                Util.inherits(Custom, Error);
                 delete Custom.name; // Ensure that the type is anonymous
 
                 try {
@@ -1221,6 +1212,21 @@ describe('expect()', () => {
                 Hoek.assert(exception.at.line !== Code.thrownAt(failed).line, 'Reports the wrong line number');
                 Hoek.assert(exception.at.filename === __filename, `expected ${exception.at.filename} to equal ${__filename}`);
             });
+
+            it('validates assertion (error)', () => {
+
+                try {
+                    Code.expect({}).to.not.exist();
+                }
+                catch (err) {
+                    var exception = err;
+                }
+
+                Hoek.assert(exception.message === 'Expected {} to not exist', exception);
+                Hoek.assert(exception.actual === undefined, exception);
+                Hoek.assert(exception.expected === undefined, exception);
+                Hoek.assert(exception.at.filename === __filename, `expected ${exception.at.filename} to equal ${__filename}`);
+            });
         });
 
         describe('empty()', () => {
@@ -1374,6 +1380,11 @@ describe('expect()', () => {
                     Code.expect(Object.create(null)).to.not.equal({}, { prototype: true });
                     Code.expect(Object.create(null)).to.equal({}, { prototype: false });
                     Code.expect(Object.create(null)).to.equal({});
+                    Code.expect({ a: 1, b: 2 }).to.equal({ a: 1, b: 3 }, { skip: ['b'] });
+
+                    const f1 = () => { };
+                    const f1a = () => { };
+                    Code.expect({ f1 }).to.equal({ f1: f1a });
                 }
                 catch (err) {
                     var exception = err;
@@ -2411,4 +2422,25 @@ describe('thrownAt()', () => {
 
         Hoek.assert(at === undefined, 'Reports the wrong at information');
     });
+
+    it('handles error with unnamed functions', () => {
+
+        const test = (f) => f();
+
+        try {
+
+            // eslint-disable-next-line prefer-arrow-callback
+            test(function () {
+
+                Code.expect(true).to.be.false();
+            });
+
+            Code.fail('an error should have been thrown');
+        }
+        catch (ex) {
+
+            const at = Code.thrownAt(ex);
+            Hoek.assert(at.filename === __filename);
+        }
+    });
 });
